'use strict';

var _lodash = require('lodash');

var _lodash2 = _interopRequireDefault(_lodash);

var _ViewerContext = require('../models/ViewerContext.js');

var _ViewerContext2 = _interopRequireDefault(_ViewerContext);

var _fs = require('fs');

var _fs2 = _interopRequireDefault(_fs);

var _path = require('path');

var _path2 = _interopRequireDefault(_path);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function BaseController(req, res) {
  this.config = req.app.locals.config;
  this.req = req;
  this.res = res;
  this.viewerContext = null;

  if (this.config.manifestPath) {
    this.manifest = JSON.parse(_fs2.default.readFileSync(this.config.manifestPath, { encoding: 'utf-8' }));
  }

  return _ViewerContext2.default.genFromViewerContextID(this.req.session.viewerContextID, this.setReqSession.bind(this), this.config.PRIMARY_ACCOUNT_KEY);
}

_lodash2.default.extend(BaseController.prototype, {
  setReqSession: function setReqSession(err, viewerContext) {
    if (viewerContext) {
      this.viewerContext = viewerContext;

      if (this.req.session.viewerContextID !== viewerContext.id) {
        this.req.session.viewerContextID = viewerContext.id;
      }
      return this.genResponse();
    } else {
      return this.res.redirect('/');
    }
  },

  setAssets: function setAssets(params) {
    params.jsBundle = this.manifest.javascript ? this.manifest.javascript[params.initScript] : this.manifest[params.initScript + '.js'];
    params.cssBundle = this.manifest.styles ? this.manifest.styles[params.initScript] : this.manifest[params.initScript + '.css'];
    return params;
  },

  getSessionID: function getSessionID() {
    return this.req ? this.req.sessionID : null;
  },

  getViewerContext: function getViewerContext() {
    return this.viewerContext;
  },

  getBootloaderParams: function getBootloaderParams(filename) {
    var initScript = '';

    initScript += filename;

    var params = {
      initScript: initScript
    };
    if (this.manifest) {
      return this.setAssets(params);
    } else {
      return params;
    }
  },

  genResponse: function genResponse() {
    console.error('Implement me!');
  }
});

module.exports = BaseController;