'use strict';

var PATH = require('path');
var ROOT = '../';
var baseManager = require('./base-manager');
var compression = require('compression');
var methodOverride = require('method-override');
var bodyParser = require('body-parser');
var errorHandler = require('errorhandler');
var logger = require('morgan');
var helmet = require('helmet');
var express = require('express');
var configManager = Object.assign({}, baseManager, {
  configureCommon: function configureCommon(app, io) {
    app.use(compression());
    app.use(methodOverride());
    app.set('view engine', 'pug');
    app.set('views', app.config.VIEWS_PATH);
    app.use(bodyParser.urlencoded({
      extended: true
    }));
    app.use(bodyParser.json({ strict: false }));
    app.locals.config = app.config;
    app.use(express['static'](app.config.STATIC_PATH));
    app.use(function (req, res, next) {
      return next();
    });
  },
  configureProductionEnv: function configureProductionEnv(app, io) {
    app.locals.pretty = false;
    app.use(logger('combined'));
    app.use(errorHandler());
    app.enable('trust proxy');
  },
  configureDevelopmentEnv: function configureDevelopmentEnv(app, io) {
    app.locals.pretty = true;
    app.use(logger('dev'));
    require('longjohn');
    app.use(errorHandler({
      dumpExceptions: true,
      showStack: true
    }));
  }
});

module.exports = configManager;