'use strict';

// Allows for relative paths
require('./_include.js');
require('babel-register')({
  presets: ['env']
});

var PATH = require('path');
var production = process.env.NODE_ENV === 'production';
var winston = require('winston');
var expressWinston = require('express-winston');
var http = require('http');
var express = require('express');
var app = express();
var server = http.createServer(app);
var io = require('socket.io')(server);
var sessionManager = include('infra/session-manager');
var configManager = include('infra/config-manager');
var parseManager = include('infra/parse-manager');
var ghostManager = include('infra/ghost-manager');
var BaseController = include('controllers/BaseController.js');
var BaseSocketController = include('controllers/BaseSocketController.js');
var ViewerContext = include('models/ViewerContext.js');

var defaultConfig = {
  host: "localhost",
  port: "8888",
  MONGO_DB: "OHM",
  MONGO_PORT: "27017",
  MONGO_HOST: "localhost",
  REDIS_PORT: "6379",
  REDIS_HOST: "localhost",
  PARSE_PATH: "/parse",
  PARSE_DASHBOARD: "/dashboard",
  PARSE_APPLICATION_ID: "OHMTEST",
  PARSE_JAVASCRIPT_KEY: "OHMTEST",
  PARSE_MASTER_KEY: "OHMTEST",
  SOCKETIO_SESSION_SECRET: "OHMTEST",
  SESSION_KEY: "OHMTEST",
  PRIMARY_ACCOUNT_KEY: "OHMTEST"
};

function Ohm(config) {
  Object.keys(config).map(function (key, index) {
    defaultConfig[key] = config[key];
  });

  config = defaultConfig;
  app.config = config;

  winston.info('Server starting on port ' + config.port + ' in ' + app.settings.env + ' mode');
  configManager.handle(app);

  if (config.SESSION_KEY) {
    parseManager.handle(app);
    sessionManager.handle(app, io);
  }

  if (config.GHOST_CONFIG_PATH) {
    ghostManager.handle(app);
  }

  app.use(expressWinston.logger({
    transports: [new winston.transports.File({
      filename: 'logs/ohm.debug.log',
      level: 'debug'
    })]
  }));

  if (config.SOCKETS) {
    require(config.SOCKETS)(io, app);
  }
  require(config.ROUTES)(app);

  app.use(expressWinston.errorLogger({
    transports: [new winston.transports.File({

      filename: 'logs/ohm.error.log'
    })]
  }));

  server.listen(config.port);
  return server;
}

exports = module.exports = Ohm;
exports.BaseController = BaseController;
exports.BaseSocketController = BaseSocketController;
exports.ViewerContext = ViewerContext;